<template>
  <div class="riskBox">
    <el-form ref="formRef" :model="state.formData" :rules="state.rules" class="register-form" label-position="top">
      <el-row :gutter="30">
        <el-col :span="6">
          <el-button type="primary" @click="addRectify('add',{})">新增整改</el-button>
        </el-col>
      </el-row>
      <el-table :data="state.recitificationList" :border="true" style="margin: 20px 0">
        <el-table-column label="序号" width="60" align="center" type="index"></el-table-column>
        <el-table-column label="整改时间" prop="rectifyTime" align="center"></el-table-column>
        <el-table-column label="提交时间" prop="updateTime" align="center"></el-table-column>
        <el-table-column label="整改说明" prop="reason" align="center"></el-table-column>
        <el-table-column label="整改人" prop="rectifyPerson" align="center"></el-table-column>
        <el-table-column label="附件" prop="" align="center">
          <template #default="scope">
            <span @click="handlePreview(scope.row.accessoryFile)" style="color: #3b82f6;cursor:pointer">{{scope.row.accessoryFile.originName}}</span>
          </template>
        </el-table-column>
        <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
          <template #default="scope">
            <el-button link type="primary" @click="addRectify('edit',scope.row)">编辑</el-button>
            <el-button link type="danger" @click="del(scope.row)">删除</el-button>
          </template>
        </el-table-column>
      </el-table>
    </el-form>
    <div class="pag-container">
      <el-pagination
          v-model:current-page="state.queryParams.pageNum"
          v-model:page-size="state.queryParams.pageSize"
          :page-sizes="[10,15,20,25]"
          layout="total, sizes, prev, pager, next, jumper"
          :total="total"
          @size-change="handleSizeChange"
          @current-change="handleCurrentChange"
      />
    </div>
    <confirm-end-dialog ref="confirmRef" @getList="getList(props.projectId)"></confirm-end-dialog>
  </div>

</template>
<script setup>

import {defineEmits, defineProps, onMounted, reactive, ref} from "vue";
import {ElMessage, ElMessageBox} from "element-plus";
import {addRecord, editRecord, getDetail} from "@/api/projectManage/contractMng";
import Cookies from "js-cookie";
import { getToken } from "@/utils/auth";
import confirmEndDialog from './confirmEndDialog.vue'
import {delProject, getAccessoryFile} from "@/api/projectManage/project";
import {delRecitification, doConfirm, getRecognitionList} from "@/api/projectManage/riskAnalysis";
import axios from "axios";

const confirmRef = ref(null);
const emit = defineEmits(["getNextStatus"]);
const props = defineProps(['projectId'])
const state = reactive({
  formData: {},
  queryParams: {
    pageNum: 1,
    pageSize: 10,
  },
  recitificationList: [],
})

const total = ref(0);
const isAmin = ref(false)
const formRef = ref();
onMounted(() => {
  const userInfo = JSON.parse(Cookies.get('userInfo'))
  if(userInfo.identity === 0){
    isAmin.value = true;
  }
  if(props.projectId){
    state.formData.projectId = props.projectId;
    getList(state.formData.projectId);
  }
});


const getList = async (val) => {
  const res = await getRecognitionList({projectId: val});
  if(res.code == 200){
    state.recitificationList = res.data.list;
    total.value = res.data.total;
  }else {
    ElMessage.warning(res.message)
  }
}

const riskOpen = async (type,val) => {
  // await  getList(val);
  state.formData.projectId = val;
  if(type === 'confirm') {
    const res = await doConfirm({projectId: val});
    if (res.code == 200) {
      ElMessage.success('保存成功')
      formRef.value.clearValidate();
      emit('getNextStatus', state.formData.projectId);
    } else {
      ElMessage.warning(res.message)
    }
  }
}

const addRectify = (type,val)=>{
  val.projectId =  state.formData.projectId;
  confirmRef.value.openDialog(type,val)
}

const delRectify = (index)=>{
  state.rectifyList.splice(index,1)
}
const handleSizeChange = (val) => {
  state.queryParams.pageNum = 1;
  state.queryParams.pageSize = val
  getList(props.projectId)
}
const handleCurrentChange = (val) => {
  state.queryParams.pageNum = val
  getList(props.projectId)
}

// 图片上传
const showTip =()=>{
  ElMessage({
    type: 'warning',
    message: '超出文件上传数量'
  });
}

const picSize = async (rawFile) => {
  if(rawFile.size / 1024 / 1024 > 5){
    ElMessage({
      type: 'warning',
      message: '文件大小不能超过5M'
    });
    return false
  }
};

const handleAvatarSuccess = (res, uploadFile) => {
  if(res.code == 200){
    // state.registerForm.agency.reportPath = res.data.path
  }else{
    ElMessage({
      type: 'warning',
      message: '文件上传失败'
    })
  }
}

const handleRemove = async (file, uploadFiles) => {
  const res = await delPic({path: state.registerForm.agency.reportPath})
  if(res.code == 200){
    ElMessage({
      type: 'success',
      message: '文件已删除'
    })
  }else{
    ElMessage({
      type: 'warning',
      message: res.message
    })
  }
}
const handlePreview = (file) => {
  const url = import.meta.env.VITE_APP_BASE_API + '/' + file.path
  axios.get( url,{
        headers:
            {
              'Content-Type': 'application/json',
              'Authorization':getToken(),
            },
        responseType: 'blob'
      }
  ).then(res=>{
    if (res) {
      const link = document.createElement('a')
      let blob = new Blob([res.data],{type: res.data.type})
      link.style.display = "none";
      link.href = URL.createObjectURL(blob); // 创建URL
      link.setAttribute("download", file.originName);
      document.body.appendChild(link);
      link.click();
      document.body.removeChild(link);
    } else {
      this.$message.error('获取文件失败')
    }
  })
}
const del = (val) => {
  ElMessageBox.confirm(
      '确定删除此条数据？',
      '提示',
      {
        confirmButtonText: '确定',
        cancelButtonText: '取消',
        type: 'warning',
      })
      .then( async() => {
        const res = await delRecitification(val)
        if(res.code == 200){
          ElMessage.success('数据删除成功')
          getList(props.projectId)
        }else{
          ElMessage.warning(res.message)
        }
      })
}

defineExpose({
  riskOpen
});


</script>
<style scoped lang="scss">
.riskBox{
  :deep(.el-form .el-form-item__label) {
    font-size: 15px;
  }
}
.pag-container{
  float: right;
  margin-top: 20px;
}

</style>
